@@ -1,36 +1,36 @@
-
 #' Download additional data collected by annee politique suisse (the complete SwissVotes-Database)
 #'
 #' \code{get_swissvotes} downloads additional data collected by annee politique suisse. It allows for completely downloading their database. Please cite data.
 #'
-#'   get_swissvotes - retrieve data on votes. The unit of analysis are votes.
+#' get_swissvotes - retrieve data on votes. The unit of analysis are votes.
 #'
 #' @param DB get database
 #' @param savecitation by default = FALSE. Saves the citation within a .txt file in the working directory if TRUE.
 #' @param codebook by default = FALSE. If TRUE navigates your browser to the codebook.
+#' 
 #' @export
-#' @rdname get_swissvotes
+#' 
 #' @return a tibble containing the results
+#' 
 #' @examples
 #'
-# results <-get_swissvotes(DB=TRUE, savecitation=FALSE, codebook=FALSE)
+# results <- get_swissvotes(DB=TRUE, savecitation=FALSE, codebook=FALSE)
 #' 
 #' # See codebook only
-#'  get_swissvotes(codebook=FALSE)
-#'
+#' get_swissvotes(codebook=FALSE)
 #' 
-#'
-
-get_swissvotes <- function(DB=T, savecitation=F, codebook=F){
-
-  if(DB){
-    swissvotesDB <- utils::read.csv("https://swissvotes.ch/page/dataset/swissvotes_dataset.csv",
-                             sep=";", stringsAsFactors = F)
-  }
-
-
-  if(codebook) utils::browseURL("https://swissvotes.ch/storage/6fe1c47ea920f8449eb3bd6d91e1df7a0316c976431a02762e2508d0102d7724")
+get_swissvotes <- function(DB = T, savecitation = F, codebook = F) {
 
+  if (DB) {
+    
+    swissvotesDB <- utils::read.csv(
+      "https://swissvotes.ch/page/dataset/swissvotes_dataset.csv",
+      sep=";", 
+      stringsAsFactors = F
+      )
+    
+    }
+  if (codebook) utils::browseURL("https://swissvotes.ch/page/dataset/codebook-de.pdf")
 
   if(DB) {
 
